@@ -1,31 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2017 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the Qt Network Auth module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 or (at your option) any later version
-** approved by the KDE Free Qt Foundation. The licenses are as published by
-** the Free Software Foundation and appearing in the file LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2017 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #ifndef QT_NO_HTTP
 
@@ -319,8 +293,12 @@ void QOAuth2AuthorizationCodeFlow::refreshAccessToken()
 
     using Key = QAbstractOAuth2Private::OAuth2KeyString;
 
-    QVariantMap parameters;
+    QMultiMap<QString, QVariant> parameters;
     QNetworkRequest request(d->accessTokenUrl);
+#ifndef QT_NO_SSL
+    if (d->sslConfiguration && !d->sslConfiguration->isNull())
+        request.setSslConfiguration(*d->sslConfiguration);
+#endif
     QUrlQuery query;
     parameters.insert(Key::grantType, QStringLiteral("refresh_token"));
     parameters.insert(Key::refreshToken, d->refreshToken);
@@ -356,7 +334,7 @@ void QOAuth2AuthorizationCodeFlow::refreshAccessToken()
     \l {https://tools.ietf.org/html/rfc6749#section-4.1.1}
     {Authorization Request} using \a parameters.
 */
-QUrl QOAuth2AuthorizationCodeFlow::buildAuthenticateUrl(const QVariantMap &parameters)
+QUrl QOAuth2AuthorizationCodeFlow::buildAuthenticateUrl(const QMultiMap<QString, QVariant> &parameters)
 {
     Q_D(QOAuth2AuthorizationCodeFlow);
     using Key = QAbstractOAuth2Private::OAuth2KeyString;
@@ -366,7 +344,7 @@ QUrl QOAuth2AuthorizationCodeFlow::buildAuthenticateUrl(const QVariantMap &param
     Q_ASSERT(!d->state.isEmpty());
     const QString state = d->state;
 
-    QVariantMap p(parameters);
+    QMultiMap<QString, QVariant> p(parameters);
     QUrl url(d->authorizationUrl);
     p.insert(Key::responseType, responseType());
     p.insert(Key::clientIdentifier, d->clientIdentifier);
@@ -393,8 +371,12 @@ void QOAuth2AuthorizationCodeFlow::requestAccessToken(const QString &code)
     Q_D(QOAuth2AuthorizationCodeFlow);
     using Key = QAbstractOAuth2Private::OAuth2KeyString;
 
-    QVariantMap parameters;
+    QMultiMap<QString, QVariant> parameters;
     QNetworkRequest request(d->accessTokenUrl);
+#ifndef QT_NO_SSL
+    if (d->sslConfiguration && !d->sslConfiguration->isNull())
+        request.setSslConfiguration(*d->sslConfiguration);
+#endif
     QUrlQuery query;
     parameters.insert(Key::grantType, QStringLiteral("authorization_code"));
     parameters.insert(Key::code, QUrl::toPercentEncoding(code));
@@ -429,7 +411,7 @@ void QOAuth2AuthorizationCodeFlow::requestAccessToken(const QString &code)
     interaction.
 */
 void QOAuth2AuthorizationCodeFlow::resourceOwnerAuthorization(const QUrl &url,
-                                                              const QVariantMap &parameters)
+                                                              const QMultiMap<QString, QVariant> &parameters)
 {
     Q_D(QOAuth2AuthorizationCodeFlow);
     if (Q_UNLIKELY(url != d->authorizationUrl)) {
@@ -445,4 +427,6 @@ void QOAuth2AuthorizationCodeFlow::resourceOwnerAuthorization(const QUrl &url,
 
 QT_END_NAMESPACE
 
+#include "moc_qoauth2authorizationcodeflow.cpp"
+
 #endif // QT_NO_HTTP
